==> slf4j-1.5.10.tar.gz: slf4j-1.5.10/site/templates/left.js <==

document.write('<div class="menuGroup">');
document.write('  <p class="menu_header">SLF4J Project</p>');
document.write('    <a href="index.html">Introduction</a>');
document.write('    <a href="news.html">News</a>');
document.write('    <a href="docs.html">Documentation</a>');
document.write('    <a href="license.html">License</a>');
document.write('    <a href="download.html">Download</a>');

document.write('    <a href="repos.html">Source Repository</a>');
document.write('    <a href="mailing-lists.html">Mailing Lists</a>');
document.write('    <a href="bug-reporting.html">Bug Reporting</a>');

document.write('  <p class="menu_header">Native implementations</p>');
document.write('    <a href="http://logback.qos.ch/">Logback</a>');
document.write('    <a href="http://www.x4juli.org">x4juli</a>');
document.write('    <p class="menu_header">Wrapped implementations</p>');
document.write('    <a href="api/org/slf4j/impl/JDK14LoggerAdapter.html">JDK14</a>');
document.write('    <a href="api/org/slf4j/impl/Log4jLoggerAdapter.html">Log4j</a>');
document.write('    <a href="api/org/slf4j/impl/SimpleLogger.html">Simple</a>');
document.write('    <a href="http://simple-log.dev.java.net/">Simple-log</a>');
document.write('  </p>');

document.write('  <p class="menu_header">Sub-projects</p>');
document.write('    <a href="http://www.slf4j.org/android/">slf4j-android</a>');
document.write('    <a href="http://www.slf4j.org/taglib/">slf4j-taglib</a>');
document.write('  </p>');

document.write('</div>');

document.write('<p>&nbsp;</p>');
document.write('<p class="pub">');
document.write('  <a href="https://www.qos.ch/shop/products/log4j/log4j-Manual.jsp">');
document.write('    <img src="images/buyDirect.jpg" border="0" title="" alt="buy direct from the developer"/>');
document.write('  </a>');
document.write('</p>');

==> slf4j-1.6.6.tar.gz: slf4j-1.6.6/site/templates/left.js <==

document.write('<div class="menuGroup">');
document.write('  <p class="menu_header">SLF4J Project</p>');
document.write('    <a href="index.html">Introduction</a>');
document.write('    <a href="download.html">Download</a>');
document.write('    <a href="docs.html">Documentation</a>');
document.write('    <a href="license.html">License</a>');
document.write('    <a href="news.html">News</a>');

document.write('  <p class="menu_header">Support</p>');

document.write('    <a href="mailing-lists.html">Mailing Lists</a>');
document.write('    <a href="bug-reporting.html">Bug Reporting</a>');
document.write('    <a href="https://github.com/qos-ch/slf4j">Source Repository</a>');
document.write('    <a href="http://www.qos.ch/shop/products/professionalSupport">Support offerings</a>');
document.write('    <a href="http://www.qos.ch/shop/products/training">Training</a>');

document.write('  <p class="menu_header">Native implementations</p>');
document.write('    <a href="http://logback.qos.ch/">Logback</a>');

document.write('    <p class="menu_header">Wrapped implementations</p>');
document.write('    <a href="http://bmc.github.com/avsl/">AVSL</a>');
document.write('    <a href="api/org/slf4j/impl/JDK14LoggerAdapter.html">JDK14</a>');
document.write('    <a href="api/org/slf4j/impl/Log4jLoggerAdapter.html">Log4j</a>');
document.write('    <a href="api/org/slf4j/impl/SimpleLogger.html">Simple</a>');
document.write('  </p>');

document.write('  <p class="menu_header">Sub-projects</p>');
document.write('    <a href="http://www.slf4j.org/android/">slf4j-android</a>');
document.write('    <a href="http://www.slf4j.org/taglib/">slf4j-taglib</a>');
document.write('  </p>');

document.write('</div>');


document.write('<p>&nbsp;</p>');
document.write('<p class="pub">');
document.write('  <a href="https://www.qos.ch/shop/products/log4jManual">');
document.write('    <img src="images/buyDirect.jpg" border="0" title="" alt="buy direct from the developer"/>');
document.write('  </a>');
document.write('</p>');
